summaryrefslogtreecommitdiffstats
path: root/lib/kotext/KoTextZoomHandler.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kotext/KoTextZoomHandler.cpp')
-rw-r--r--lib/kotext/KoTextZoomHandler.cpp24
1 files changed, 12 insertions, 12 deletions
diff --git a/lib/kotext/KoTextZoomHandler.cpp b/lib/kotext/KoTextZoomHandler.cpp
index acd2285d..e9fc430f 100644
--- a/lib/kotext/KoTextZoomHandler.cpp
+++ b/lib/kotext/KoTextZoomHandler.cpp
@@ -36,39 +36,39 @@ int KoTextZoomHandler::fontSizeToLayoutUnit( double ptSizeFloat, bool forPrint )
}
#endif
-double KoTextZoomHandler::tqlayoutUnitToFontSize( int luSize, bool /*forPrint*/ ) const
+double KoTextZoomHandler::layoutUnitToFontSize( int luSize, bool /*forPrint*/ ) const
{
// TQt will use TQPaintDevice::x11AppDpiY() to go from pt to pixel for fonts
- return tqlayoutUnitPtToPt( luSize ) * m_zoomedResolutionY
+ return layoutUnitPtToPt( luSize ) * m_zoomedResolutionY
#ifdef Q_WS_X11
/ POINT_TO_INCH(TQPaintDevice::x11AppDpiY())
#endif
;
}
-int KoTextZoomHandler::tqlayoutUnitToPixelX( int x, int w ) const
+int KoTextZoomHandler::layoutUnitToPixelX( int x, int w ) const
{
// We call tqlayoutUnitToPixelX on the right value, i.e. x+w-1,
// and then determine the height from the result (i.e. right-left+1).
- // Calling tqlayoutUnitToPixelX(w) leads to rounding problems.
- return tqlayoutUnitToPixelY( x + w - 1 ) - tqlayoutUnitToPixelY( x ) + 1;
+ // Calling layoutUnitToPixelX(w) leads to rounding problems.
+ return layoutUnitToPixelY( x + w - 1 ) - layoutUnitToPixelY( x ) + 1;
}
-int KoTextZoomHandler::tqlayoutUnitToPixelY( int y, int h ) const
+int KoTextZoomHandler::layoutUnitToPixelY( int y, int h ) const
{
// We call tqlayoutUnitToPixelY on the bottom value, i.e. y+h-1,
// and then determine the height from the result (i.e. bottom-top+1).
- // Calling tqlayoutUnitToPixelY(h) leads to rounding problems.
- return tqlayoutUnitToPixelY( y + h - 1 ) - tqlayoutUnitToPixelY( y ) + 1;
+ // Calling layoutUnitToPixelY(h) leads to rounding problems.
+ return layoutUnitToPixelY( y + h - 1 ) - layoutUnitToPixelY( y ) + 1;
}
-int KoTextZoomHandler::tqlayoutUnitToPixelX( int lupix ) const
+int KoTextZoomHandler::layoutUnitToPixelX( int lupix ) const
{
return int( static_cast<double>( lupix * m_zoomedResolutionX )
/ ( static_cast<double>( m_layoutUnitFactor ) * m_resolutionX ) );
}
-int KoTextZoomHandler::tqlayoutUnitToPixelY( int lupix ) const
+int KoTextZoomHandler::layoutUnitToPixelY( int lupix ) const
{
// tqRound replaced with a truncation, too many problems (e.g. bottom of parags)
return int( static_cast<double>( lupix * m_zoomedResolutionY )
@@ -36,39 +36,39 @@ int KoTextZoomHandler::fontSizeToLayoutUnit( double ptSizeFloat, bool forPrint )
{
- // We call tqlayoutUnitToPixelX on the right value, i.e. x+w-1,
+ // We call layoutUnitToPixelX on the right value, i.e. x+w-1,
// and then determine the height from the result (i.e. right-left+1).
@@ -36,39 +36,39 @@ int KoTextZoomHandler::fontSizeToLayoutUnit( double ptSizeFloat, bool forPrint )
{
- // We call tqlayoutUnitToPixelY on the bottom value, i.e. y+h-1,
+ // We call layoutUnitToPixelY on the bottom value, i.e. y+h-1,
// and then determine the height from the result (i.e. bottom-top+1).